//
//  View.m
//  Pinch
//
//  Created by Mark Meretzky on 10/26/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import "View.h"

@implementation View

- (id) initWithFrame: (CGRect) frame
{
	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		self.backgroundColor = [UIColor whiteColor];
		CGSize view = self.bounds.size;
		original = CGSizeMake(view.width / 2, view.width / 4);

		CGRect f = CGRectMake(
			(view.width - original.width) / 2,
			(view.height - original.height) / 2,
			original.width,
			original.height
		);

		label = [[UILabel alloc] initWithFrame: f];
		label.backgroundColor = [UIColor yellowColor];
		label.textAlignment = NSTextAlignmentCenter;

		UIPinchGestureRecognizer *recognizer = [[UIPinchGestureRecognizer alloc]
			initWithTarget: self action: @selector(pinch:)
		];

		oldScale = recognizer.scale;
		[self pinch: recognizer];
		[self addGestureRecognizer: recognizer];
		[self addSubview: label];
	}
	return self;
}

- (void) pinch: (UIPinchGestureRecognizer *) recognizer
{
	CGFloat scale = recognizer.scale;

	label.bounds = CGRectMake(
		(self.bounds.size.width - original.width * scale) / 2,
		(self.bounds.size.height - original.height * scale) / 2,
		original.width  * scale,
		original.height * scale
	);

	label.font = [UIFont systemFontOfSize: 20 * scale];
	NSString *verdict = nil;

	if (scale > oldScale) {
		verdict = @"spread";
	} else if (scale < oldScale) {
		verdict = @"pinch";
	} else {
		verdict = @"neither";
	}

	oldScale = scale;
	label.text = [NSString stringWithFormat: @"%@ %g", verdict, scale];
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void) drawRect: (CGRect) rect
{
	// Drawing code
}
*/

@end
